import unittest
from geothai import (
    get_all_districts,
    get_district_by_code,
    get_districts_by_criterion,
    District
)


class TestDistrictService(unittest.TestCase):
    def test_should_retrieve_all_districts(self):
        districts = get_all_districts()
        self.assertIsInstance(districts, list)
        self.assertGreater(len(districts), 0)

    def test_should_retrieve_a_district_by_code(self):
        district_code = '1001'
        district = get_district_by_code(district_code)
        self.assertIsNotNone(district)
        self.assertEqual(district['code'], int(district_code))

    def test_should_return_none_for_an_invalid_district_code(self):
        invalid_district_code = '99999'
        district = get_district_by_code(invalid_district_code)
        self.assertIsNone(district)

    def test_should_retrieve_districts_by_a_specific_criterion(self):
        criterion: District = {'name_en': 'Phra Nakhon'}
        districts = get_districts_by_criterion(criterion)
        self.assertIsInstance(districts, list)
        self.assertGreater(len(districts), 0)
        self.assertEqual(districts[0]['name_en'], 'Phra Nakhon')

    def test_should_return_an_empty_list_for_a_non_matching_criterion(self):
        criterion: District = {'name_en': 'Non-Existent District'}
        districts = get_districts_by_criterion(criterion)
        self.assertIsInstance(districts, list)
        self.assertEqual(len(districts), 0)


if __name__ == '__main__':
    unittest.main()



import unittest
from geothai import (
    get_all_postal_codes,
    get_postal_codes_by_code
)


class TestPostalCodeService(unittest.TestCase):
    def test_should_retrieve_all_postal_codes(self):
        postal_codes = get_all_postal_codes()
        self.assertIsInstance(postal_codes, list)
        self.assertGreater(len(postal_codes), 0)

    def test_should_retrieve_a_postal_code_by_code(self):
        postal_code_code = '10200'
        postal_code = get_postal_codes_by_code(postal_code_code)
        self.assertIsNotNone(postal_code)
        self.assertEqual(postal_code['code'], int(postal_code_code))

    def test_should_return_none_for_an_invalid_postal_code_code(self):
        invalid_postal_code_code = '99999'
        postal_code = get_postal_codes_by_code(invalid_postal_code_code)
        self.assertIsNone(postal_code)


if __name__ == '__main__':
    unittest.main()



import json
from typing import List, Optional

from geothai.utils.criteria_matcher import match_criteria
from geothai.types.subdistrict_type import (
    Subdistrict, SubdistrictIndex, Subdistricts
)


with open('geothai/data/subdistricts.json', "r", encoding="utf-8") as f:
    _subdistricts_data: Subdistricts = json.load(f)


def get_all_subdistricts() -> Subdistricts:
    """Return a list of all subdistrict records."""
    return list(_subdistricts_data.values())


def get_subdistrict_by_code(code: SubdistrictIndex) -> Optional[Subdistrict]:
    """Return a single subdistrict by its code, or None if not found."""
    return _subdistricts_data.get(code)


def get_subdistricts_by_criterion(criterion: Subdistrict) -> List[Subdistrict]:
    """Return a list of subdistricts that match the given criterion."""
    return [d for d in
            _subdistricts_data.values() if match_criteria(d, criterion)]



import json
from typing import List, Optional

from geothai.utils.criteria_matcher import match_criteria
from geothai.types.province_type import Province, ProvinceIndex, Provinces


with open('geothai/data/provinces.json', "r", encoding="utf-8") as f:
    _provinces_data: Provinces = json.load(f)


def get_all_provinces() -> Provinces:
    """Return a list of all province records."""
    return list(_provinces_data.values())


def get_province_by_code(code: ProvinceIndex) -> Optional[Province]:
    """Return a single province by its code, or None if not found."""
    return _provinces_data.get(code)


def get_provinces_by_criterion(criterion: Province) -> List[Province]:
    """Return a list of provinces that match the given criterion."""
    return [d for d in
            _provinces_data.values() if match_criteria(d, criterion)]



import json
from typing import List, Optional

from geothai.utils.criteria_matcher import match_criteria
from geothai.types.district_type import District, DistrictIndex, Districts


with open('geothai/data/districts.json', "r", encoding="utf-8") as f:
    _districts_data: Districts = json.load(f)


def get_all_districts() -> Districts:
    """Return a list of all district records."""
    return list(_districts_data.values())


def get_district_by_code(code: DistrictIndex) -> Optional[District]:
    """Return a single district by its code, or None if not found."""
    return _districts_data.get(code)


def get_districts_by_criterion(criterion: District) -> List[District]:
    """Return a list of districts that match the given criterion."""
    return [d for d in
            _districts_data.values() if match_criteria(d, criterion)]



import json
import unittest
from geothai import metadata, Metadata

with open('geothai/data/metadata.json', "r", encoding="utf-8") as f:
    _expected_metadata: Metadata = json.load(f)


class TestDistrictService(unittest.TestCase):
    def test_should_match_the_expected_metadata(self):
        self.assertEqual(metadata, _expected_metadata)


if __name__ == '__main__':
    unittest.main()



import json


from .services.province_service import (
    get_all_provinces,
    get_province_by_code,
    get_provinces_by_criterion,
    Province,
    ProvinceIndex,
    Provinces
)
from .services.district_service import (
    get_all_districts,
    get_district_by_code,
    get_districts_by_criterion,
    District,
    DistrictIndex,
    Districts
)
from .services.subdistrict_service import (
    get_all_subdistricts,
    get_subdistrict_by_code,
    get_subdistricts_by_criterion,
    Subdistrict,
    SubdistrictIndex,
    Subdistricts
)
from .services.postal_code_service import (
    get_all_postal_codes,
    get_postal_codes_by_code,
    PostalCode,
    PostalCodeIndex,
    PostalCodes
)
from .types.metadata_type import Metadata

with open('geothai/data/metadata.json', "r", encoding="utf-8") as f:
    metadata: Metadata = json.load(f)

__all__ = [
    'get_all_provinces',
    'get_province_by_code',
    'get_provinces_by_criterion',
    'Province',
    'ProvinceIndex',
    'Provinces',

    'get_all_districts',
    'get_district_by_code',
    'get_districts_by_criterion',
    'District',
    'DistrictIndex',
    'Districts',

    'get_all_subdistricts',
    'get_subdistrict_by_code',
    'get_subdistricts_by_criterion',
    'Subdistrict',
    'SubdistrictIndex',
    'Subdistricts',

    'get_all_postal_codes',
    'get_postal_codes_by_code',
    'PostalCode',
    'PostalCodeIndex',
    'PostalCodes'
]



import unittest
from geothai import (
    get_all_subdistricts,
    get_subdistrict_by_code,
    get_subdistricts_by_criterion,
    Subdistrict
)


class TestSubdistrictService(unittest.TestCase):
    def test_should_retrieve_all_subdistricts(self):
        subdistricts = get_all_subdistricts()
        self.assertIsInstance(subdistricts, list)
        self.assertGreater(len(subdistricts), 0)

    def test_should_retrieve_a_subdistrict_by_code(self):
        subdistrict_code = '100101'
        subdistrict = get_subdistrict_by_code(subdistrict_code)
        self.assertIsNotNone(subdistrict)
        self.assertEqual(subdistrict['code'], int(subdistrict_code))

    def test_should_return_none_for_an_invalid_subdistrict_code(self):
        invalid_subdistrict_code = '99999'
        subdistrict = get_subdistrict_by_code(invalid_subdistrict_code)
        self.assertIsNone(subdistrict)

    def test_should_retrieve_subdistricts_by_a_specific_criterion(self):
        criterion: Subdistrict = {
            'name_en': 'Phra Borom Maha Ratchawang'
        }
        subdistricts = get_subdistricts_by_criterion(criterion)
        self.assertIsInstance(subdistricts, list)
        self.assertGreater(len(subdistricts), 0)
        self.assertEqual(
            subdistricts[0]['name_en'],
            'Phra Borom Maha Ratchawang'
        )

    def test_should_return_an_empty_list_for_a_non_matching_criterion(self):
        criterion: Subdistrict = {'name_en': 'Non-Existent Subdistrict'}
        subdistricts = get_subdistricts_by_criterion(criterion)
        self.assertIsInstance(subdistricts, list)
        self.assertEqual(len(subdistricts), 0)


if __name__ == '__main__':
    unittest.main()



from typing import TypedDict


class Stats(TypedDict):
    provinces: int
    districts: int
    subdistricts: int
    postal_codes: int


class Metadata(TypedDict):
    version: str
    last_updated: str
    source: str
    stats: Stats



import unittest
from geothai import (
    get_all_provinces,
    get_province_by_code,
    get_provinces_by_criterion,
    Province
)


class TestProvinceService(unittest.TestCase):
    def test_should_retrieve_all_provinces(self):
        provinces = get_all_provinces()
        self.assertIsInstance(provinces, list)
        self.assertGreater(len(provinces), 0)

    def test_should_retrieve_a_province_by_code(self):
        province_code = '10'
        province = get_province_by_code(province_code)
        self.assertIsNotNone(province)
        self.assertEqual(province['code'], int(province_code))

    def test_should_return_none_for_an_invalid_province_code(self):
        invalid_province_code = '99999'
        province = get_province_by_code(invalid_province_code)
        self.assertIsNone(province)

    def test_should_retrieve_provinces_by_a_specific_criterion(self):
        criterion: Province = {'name_en': 'Bangkok'}
        provinces = get_provinces_by_criterion(criterion)
        self.assertIsInstance(provinces, list)
        self.assertGreater(len(provinces), 0)
        self.assertEqual(provinces[0]['name_en'], 'Bangkok')

    def test_should_return_an_empty_list_for_a_non_matching_criterion(self):
        criterion: Province = {'name_en': 'Non-Existent Province'}
        provinces = get_provinces_by_criterion(criterion)
        self.assertIsInstance(provinces, list)
        self.assertEqual(len(provinces), 0)


if __name__ == '__main__':
    unittest.main()



import json
from typing import Optional

from geothai.types.postal_code_type import (
    PostalCode, PostalCodes, PostalCodeIndex
)


with open('geothai/data/postal_codes.json', "r", encoding="utf-8") as f:
    _postal_codes_data: PostalCodes = json.load(f)


def get_all_postal_codes() -> PostalCodes:
    """Return a list of all postal code records."""
    return list(_postal_codes_data.values())


def get_postal_codes_by_code(code: PostalCodeIndex) -> Optional[PostalCode]:
    """Return a single postal code by its code, or None if not found."""
    return _postal_codes_data.get(code)
